import * as logger from './log'
import { mqttHandler } from './MqttDispatcher'
import { AHomegearItem } from './AHomegearItem'

export class HueColorTemperatureBulbItem extends AHomegearItem {
    private bright: number
    private colorTemperature: number
    private state: string
    private stateActionTopic: string
    private brightActionTopic: string
    private colorTemperatureActionTopic: string
    private brightFeedbackTopic: string
    private stateFeedbackTopic: string
    private colorTemperatureFeedbackTopic: string
    private brightTopic: string
    private stateTopic: string
    private colorTemperatureTopic: string

    constructor(floor: string, room: string, item: string, label: string, hmId: number) {
        super(floor, room, item, label, hmId)
        this.stateTopic = `${this.topicFirstPart}/state`
        this.brightTopic = `${this.topicFirstPart}/bright`
        this.colorTemperatureTopic = `${this.topicFirstPart}/colorTemperature`
        this.stateFeedbackTopic = `${this.topicFirstPart}/state/feedback`
        this.brightFeedbackTopic = `${this.topicFirstPart}/bright/feedback`
        this.colorTemperatureFeedbackTopic = `${this.topicFirstPart}/colorTemperature/feedback`
        this.stateActionTopic = `${this.actionTopicPre}/1/STATE`
        this.brightActionTopic = `${this.actionTopicPre}/1/BRIGHTNESS`
        this.colorTemperatureActionTopic = `${this.actionTopicPre}/1/COLOR_TEMPERATURE`
        this.subscribeTopics = [
            this.stateTopic,
            this.brightTopic,
            this.colorTemperatureTopic
        ]
        this.state = 'OFF'
        this.bright = 0
        this.colorTemperature = 0
    }


    processMessage(topic: string, payload: string) : void {
        switch (topic) {
            case this.stateTopic:
                this.state = payload
                mqttHandler.send(this.stateFeedbackTopic, this.state)
                if (this.state == "ON") {
                    mqttHandler.send(this.stateActionTopic, "true")
                } else {
                    mqttHandler.send(this.stateActionTopic, "false")
                }
                break
            case this.brightTopic:
                this.bright = parseInt(payload)
                mqttHandler.send(this.brightFeedbackTopic, `${this.bright}`)
                mqttHandler.send(this.brightActionTopic, `${this.bright}`)
                break
            case this.colorTemperatureTopic:
                this.colorTemperature = parseInt(payload)
                mqttHandler.send(this.colorTemperatureFeedbackTopic, `${this.colorTemperature}`)
                mqttHandler.send(this.colorTemperatureActionTopic, `${this.colorTemperature}`)
                break
        }
    }
}
